source("mcmc.r")
source("utilities.r")
source("singlevar.r")
source("metropolis.r")
source("basic_hmc.r")
source("pupdate.r")
source("logistic.r")

X <- matrix(c(1,3,7,2,4,9,2,6,
              7,8,2,9,8,0,2,8), 8, 2)
y <-        c(0,0,1,1,0,1,1,1)

colnames(X) <- c("aa","bb")

init <- list (alpha=0, beta=numeric(ncol(X)), log.sigma=0)

r <-   mcmc (lpr_logistic, init, 5000, fix = list(X=X,y=y),
             "alpha", list (metropolis, step=0.2, rep=4),
             "beta",  list (metropolis, step=0.2, rep=4),
             "log.sigma",   list (metropolis, step=0.2, rep=4))

ri <-  mcmc (ilpr_logistic, init, 5000, fix = list(X=X,y=y),
             "alpha", list (metropolis, step=0.2, rep=4),
             "beta",  list (metropolis, step=0.2, rep=4),
             "log.sigma",   list (metropolis, step=0.2, rep=4))

rs <-  mcmc (lpr_logistic, init, 5000, fix = list(X=X,y=y),
             list (singlevar, list (metropolis, step=0.2, rep=4)))

rsi <- mcmc (ilpr_logistic, init, 5000, fix = list(X=X,y=y),
             list (singlevar, list (metropolis, step=0.2, rep=4)))

ri1 <- mcmc (ilpr_logistic, init, 5000, fix = list(X=X,y=y),
             "alpha", list (metropolis, step=0.2, rep=4),
             "beta",1,list (metropolis, step=0.2, rep=4),
             "beta",2,list (metropolis, step=0.2, rep=4),
             "log.sigma",   list (metropolis, step=0.2, rep=4))

rsb <- mcmc (ilpr_logistic, init, 5000, fix = list(X=X,y=y),
             "alpha", list (metropolis, step=0.2, rep=4),
             "beta",  list (singlevar, list (metropolis, step=0.2, rep=4)),
             "log.sigma",   list (metropolis, step=0.2, rep=4))

rb0 <- mcmc (lpr_logistic, init, 5000, fix = list(X=X,y=y), rec=c("acc","step"),
            "alpha", "beta", list (basic_hmc, nsteps=20, rand.step=0.3,
                               step = 0.2),
            "alpha", "beta", list(metropolis, step=0.1),
            "log.sigma", list (metropolis, step=0.2, rep=4))

rb1 <- mcmc (lpr_logistic, init, 5000, fix = list(X=X,y=y), rec=c("acc","step"),
            "alpha", "beta", list (basic_hmc, nsteps=20, rand.step=0.3,
                               step = function (s) 0.2*exp(min(0,s$log.sigma))),
            "log.sigma", list (metropolis, step=0.2, rep=4))

rb2 <- mcmc (lpr_logistic, init, 5000, fix = list(X=X,y=y), rec=c("acc","step"),
            "alpha", "beta", list (basic_hmc, nsteps=20, rand.step=0.3,
                               step = function (s) list (alpha=0.2, 
                                beta=rep(0.2*exp(min(0,s$log.sigma)),ncol(X)))),
            "log.sigma", list (metropolis, step=0.2, rep=4))

rj <- mcmc (lpr_logistic, 
         list (alpha=0, beta=numeric(ncol(X)), log.sigma=0, y=numeric(nrow(X))),
         fix = list (X=X),
         iterations = 10000,
         list (metropolis, step=0.25, rep=20),
         list (metropolis, step=0.05, rep=10),
         list (sample_logistic_prior, level=2))

rjp <- mcmc (lpr_logistic, 
         list (alpha=0, beta=numeric(ncol(X)), log.sigma=0, y=numeric(nrow(X))),
         fix = list (X=X),
         iterations = 10000,
         list (sample_logistic_prior, level=0))
